@@ -398,7 +398,7 @@ from ae.core import DEBUG_LEVELS                                    # type: igno
 from ae.console import ConsoleApp                                   # type: ignore
 
 
-__version__ = '0.1.38'
+__version__ = '0.1.39'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -638,16 +638,15 @@ class MainAppBase(ConsoleApp, ABC):
         self.set_opt('debug_level', level)
         return True
 
-    def on_font_size_change(self, _flow_key: str, event_kwargs: Dict[str, Any]) -> bool:
+    def on_font_size_change(self, font_size_lit: str, _event_kwargs: Dict[str, Any]) -> bool:
         """ font size app state change event handler.
 
-        :param _flow_key:       flow key.
-        :param event_kwargs:    event kwargs with key `'font_size'` containing the new font size in pixels as float.
+        :param font_size_lit:   font size as string.
+        :param _event_kwargs:   unused event kwargs.
         :return:                True for to confirm change of flow id.
         """
-        font_size: float = event_kwargs['font_size']
-        self.vpo(f"MainAppBase.on_font_size_change {font_size}")
-        self.change_app_state('font_size', font_size)
+        self.vpo(f"MainAppBase.on_font_size_change {font_size_lit}")
+        self.change_app_state('font_size', float(font_size_lit))
         return True
 
     def on_lang_code_change(self, lang_code: str, _event_kwargs: Dict[str, Any]) -> bool:
@@ -793,9 +792,12 @@ class MainAppBase(ConsoleApp, ABC):
         :param popups_to_close: optional sequence of widgets to be closed on confirmed flow change.
         :param event_kwargs:    optional args to pass additional data or info onto and from the event handler.
 
-                                info pass onto event handler:
+                                info pass onto event handler (e.g. from :attr:`~ae.kivy_app.FlowButton.tap_kwargs`
+                                or :attr:`~ae.kivy_app.FlowToggler.tap_kwargs`):
                                     * `popup_kwargs`: optional dict passed to the Popup `__init__` method,
-                                       like e.g. dict(parent=parent_widget_of_popup, data=...).
+                                      like e.g. dict(parent=parent_widget_of_popup, data=...).
+                                    * `tap_widget`: optional tapped button widget instance (initiating this
+                                      flow change).
 
                                 info passed from the event handler:
                                     * `flow_id`: process :attr:`~MainAppBase.flow_path` as specified by the
